/*
 * cpr.c
 * CreateProcess,
 * WaitForSingleObject, GetExitCodeProcess Demo
 *
 * Bernhard Rabe
 *
 * 18.05.2005
 */


#include <windows.h>
#include <stdio.h>

static void ErrorExit(const char * msg, DWORD errcode)
{
    LPVOID *errmsg;
    
    if (!FormatMessage( 
        FORMAT_MESSAGE_ALLOCATE_BUFFER | 
        FORMAT_MESSAGE_FROM_SYSTEM | 
        FORMAT_MESSAGE_IGNORE_INSERTS,
        NULL,
        errcode,
        MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
        (LPTSTR) &errmsg,
        0,
        NULL )
    )
    {
        fprintf(stderr,"FormatMessage\n");
        exit(2);
    }

    fprintf(stderr, "Fehler: %s:%s\n", msg, errmsg);
    LocalFree(errmsg);
    exit(1);
}

int main(int argc, char* argv[])
{
    STARTUPINFO si;
    PROCESS_INFORMATION pi;
    DWORD status;
    
    if(argc<2)
    {
        printf("usage: %s executable\n",argv[0]);
        exit(1);
    }
    
    ZeroMemory(&si,sizeof(si));
    si.cb=sizeof(si);
    
    ZeroMemory(&pi,sizeof(pi));
    
    if( !CreateProcess(NULL,argv[1],NULL,NULL,FALSE,0,NULL,NULL,&si,&pi) )
    {
        ErrorExit("Fehler bei CreateProcess",GetLastError());
    }
    
    printf("Warte auf Beendigung vom Prozess");
    
    if(WAIT_FAILED==WaitForSingleObject(pi.hProcess,INFINITE))
    {
        ErrorExit("Fehler bei WaitForSingleObject.",GetLastError());
    }
    
    if(!GetExitCodeProcess(pi.hProcess,&status))
    {
        ErrorExit("Fehler bei GetExitCodeProcess",GetLastError());
    }
    printf("Prozess beendete sich mit %x\n",status);
    
    return 0;
}