#include <windows.h>
#include <stdio.h>

static void ErrorExit(const char * msg, DWORD errcode)
{
    LPVOID *errmsg;
    
    if (!FormatMessage( 
        FORMAT_MESSAGE_ALLOCATE_BUFFER | 
        FORMAT_MESSAGE_FROM_SYSTEM | 
        FORMAT_MESSAGE_IGNORE_INSERTS,
        NULL,
        errcode,
        MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
        (LPTSTR) &errmsg,
        0,
        NULL )
    )
    {
        fprintf(stderr,"FormatMessage\n");
        exit(2);
    }

    fprintf(stderr, "Fehler: %s:%s\n", msg, errmsg);
    LocalFree(errmsg);
    exit(1);
}

int main(int argc, char *argv[])
{
    PROCESS_INFORMATION pi;
    STARTUPINFO si;
    
    char *applicationname=NULL, *parameters=NULL;
    
    if(argc<2)
    {
        fprintf(stderr,"usage: %s applicationname [parameters]\n",argv[0]);
        return 1;
    }
    
    /*set to NULL if value is empty*/
    applicationname=(strlen(argv[1])==0)? NULL : argv[1];
    
    /*set to NULL if value is empty*/
    if(argc>2)
        parameters=(strlen(argv[2])==0)? NULL : argv[2];
    
    ZeroMemory(&pi,sizeof(pi));
    ZeroMemory(&si,sizeof(si));
    si.cb=sizeof(STARTUPINFO);    
    
    if(!CreateProcess(applicationname,parameters,NULL,NULL,FALSE,0,NULL,NULL,&si,&pi))
    {
        ErrorExit("CreateProcess",GetLastError());
    }
 
    CloseHandle(pi.hProcess);    
    return 0;
}
